@@ -345,13 +345,16 @@ class RelationshipTests(TestCase):
 
     def test_single_reverse(self):
         node_1 = LinkedNode.objects.create(
-            name="first node", prev_id=None,
+            name="first node",
+            prev_id=None,
         )
         node_2 = LinkedNode.objects.create(
-            name="next node", prev_id=node_1.id,
+            name="next node",
+            prev_id=node_1.id,
         )
         node_3 = LinkedNode.objects.create(
-            name="last node", prev_id=node_2.id,
+            name="last node",
+            prev_id=node_2.id,
         )
         self.assertEqual(node_3.prev, node_2)
         self.assertEqual(node_1.next, node_2)
@@ -371,3 +374,11 @@ class RelationshipTests(TestCase):
     def test_complex_expression(self):
         ug = UserGenerator.objects.create()
         self.assertEqual(ug.user, User.objects.get(username="generated_for_%d" % ug.id))
+
+    def test_descriptor_not_cached(self):
+        item = CartItem.objects.first()
+        self.assertIsNotNone(item.product)
+
+        item.product.delete()
+        with self.assertRaises(Product.DoesNotExist):
+            item.product
